Package: Tplyr
Title: A Traceability Focused Grammar of Clinical Data Summary
Version: 1.3.2
Authors@R: 
    c(
    person(given = "Eli",
           family = "Miller",
           role = "aut",
           email = "Eli.Miller@AtorusResearch.com",
           comment = c(ORCID = "0000-0002-2127-9456")),
    person(given = "Mike",
           family = "Stackhouse",
           role = c("aut", "cre"),
           email = "mike.stackhouse@atorusresearch.com",
           comment = c(ORCID = "0000-0001-6030-723X")),
    person(given = "Ashley", 
           family = "Tarasiewicz",
           email = "Ashley.Tarasiewicz@atorusresearch.com", 
           role = "aut"),
    person(given = "Nathan",
           family = "Kosiba",
           email = "Nathan.Kosiba@atorusresearch.com",
           role = "ctb",
           comment = c(ORCID = "0000-0001-5359-4234")),
    person(given = "Sadchla",
           family = "Mascary",
           email = "sadchla.mascary@atorusresearch.com",
           role = "ctb"),
    person(given = "Andrew",
           family = "Bates",
           email = "andrew.bates@atorusresearch.com",
           role = "ctb"),
    person(given = "Shiyu",
           family = "Chen",
           email = "shiyu.chen@atorusresearch.com",
           role = "ctb"),
    person(given = "Oleksii",
           family = "Mikryukov",
           email = "alex.mikryukov@atorusresearch.com",
           role = "ctb"),
    person(given = "Atorus Research LLC",
           role = "cph")
    )
Description: A traceability focused tool created to simplify the data manipulation necessary to create clinical summaries.
License: MIT + file LICENSE
URL: https://atorus-research.github.io/Tplyr/,
        https://github.com/atorus-research/Tplyr
BugReports: https://github.com/atorus-research/Tplyr/issues
Encoding: UTF-8
Depends: R (>= 4.1.0)
Imports: rlang (>= 0.4.6), assertthat (>= 0.2.1), magrittr (>= 1.5),
        dplyr (>= 1.0.0), purrr (>= 0.3.3), stringr (>= 1.4.0), tidyr
        (>= 1.0.2), tidyselect (>= 1.1.0), tibble (>= 3.0.1),
        lifecycle, forcats (>= 1.0.0)
Suggests: testthat (>= 2.1.0), carrier (>= 0.2.0), haven (>= 2.2.0),
        knitr, mirai, rmarkdown, huxtable, tidyverse, readr,
        kableExtra, pharmaRTF, withr
VignetteBuilder: knitr
RoxygenNote: 7.3.2
RdMacros: lifecycle
Config/testthat/edition: 3
LazyData: true
NeedsCompilation: no
Packaged: 2026-02-25 20:50:05 UTC; mstackhouse
Author: Eli Miller [aut] (ORCID: <https://orcid.org/0000-0002-2127-9456>),
  Mike Stackhouse [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6030-723X>),
  Ashley Tarasiewicz [aut],
  Nathan Kosiba [ctb] (ORCID: <https://orcid.org/0000-0001-5359-4234>),
  Sadchla Mascary [ctb],
  Andrew Bates [ctb],
  Shiyu Chen [ctb],
  Oleksii Mikryukov [ctb],
  Atorus Research LLC [cph]
Maintainer: Mike Stackhouse <mike.stackhouse@atorusresearch.com>
Repository: CRAN
Date/Publication: 2026-02-26 06:10:37 UTC
Built: R 4.6.0; ; 2026-04-30 05:21:43 UTC; unix
