# Generated by roxygen2: do not edit by hand

S3method(build,tplyr_table)
S3method(get_meta_result,data.frame)
S3method(get_meta_result,tplyr_table)
S3method(get_meta_subset,data.frame)
S3method(get_meta_subset,tplyr_table)
S3method(get_numeric_data,tplyr_layer)
S3method(get_numeric_data,tplyr_table)
S3method(get_stats_data,tplyr_layer)
S3method(get_stats_data,tplyr_table)
S3method(get_where,tplyr_layer)
S3method(get_where,tplyr_table)
S3method(print,f_str)
S3method(print,tplyr_layer)
S3method(print,tplyr_layer_template)
S3method(print,tplyr_meta)
S3method(print,tplyr_table)
S3method(process_formatting,count_layer)
S3method(process_formatting,desc_layer)
S3method(process_formatting,shift_layer)
S3method(process_metadata,count_layer)
S3method(process_metadata,desc_layer)
S3method(process_metadata,shift_layer)
S3method(process_metadata,tplyr_riskdiff)
S3method(process_metadata,tplyr_statistic)
S3method(process_statistic_data,tplyr_riskdiff)
S3method(process_statistic_formatting,tplyr_riskdiff)
S3method(process_summaries,count_layer)
S3method(process_summaries,desc_layer)
S3method(process_summaries,shift_layer)
S3method(set_denoms_by,count_layer)
S3method(set_denoms_by,shift_layer)
S3method(set_format_strings,count_layer)
S3method(set_format_strings,desc_layer)
S3method(set_format_strings,shift_layer)
S3method(set_limit_data_by,count_layer)
S3method(set_limit_data_by,desc_layer)
S3method(set_limit_data_by,shift_layer)
S3method(set_where,tplyr_layer)
S3method(set_where,tplyr_table)
S3method(str,f_str)
S3method(str,tplyr_layer)
S3method(str,tplyr_table)
export("%>%")
export("header_n<-")
export("pop_data<-")
export(add_anti_join)
export(add_column_headers)
export(add_filters)
export(add_layer)
export(add_layers)
export(add_missing_subjects_row)
export(add_risk_diff)
export(add_total_group)
export(add_total_row)
export(add_treat_grps)
export(add_variables)
export(append_metadata)
export(apply_conditional_format)
export(apply_formats)
export(apply_row_masks)
export(build)
export(collapse_row_labels)
export(f_str)
export(get_by)
export(get_count_layer_formats)
export(get_data_labels)
export(get_desc_layer_formats)
export(get_layer_template)
export(get_layer_templates)
export(get_meta_result)
export(get_meta_subset)
export(get_metadata)
export(get_numeric_data)
export(get_pop_where)
export(get_precision_by)
export(get_precision_on)
export(get_shift_layer_formats)
export(get_stats_data)
export(get_target_var)
export(get_tplyr_regex)
export(get_where)
export(group_count)
export(group_desc)
export(group_shift)
export(header_n)
export(keep_levels)
export(new_layer_template)
export(pop_data)
export(pop_treat_var)
export(process_formatting)
export(process_metadata)
export(process_statistic_data)
export(process_statistic_formatting)
export(process_summaries)
export(remove_layer_template)
export(replace_leading_whitespace)
export(set_by)
export(set_count_layer_formats)
export(set_custom_summaries)
export(set_denom_ignore)
export(set_denom_where)
export(set_denoms_by)
export(set_desc_layer_formats)
export(set_distinct_by)
export(set_format_strings)
export(set_header_n)
export(set_indentation)
export(set_limit_data_by)
export(set_missing_count)
export(set_missing_subjects_row_label)
export(set_nest_count)
export(set_numeric_threshold)
export(set_order_count_method)
export(set_ordering_cols)
export(set_outer_sort_position)
export(set_pop_data)
export(set_pop_treat_var)
export(set_pop_where)
export(set_precision_by)
export(set_precision_data)
export(set_precision_on)
export(set_result_order_var)
export(set_shift_layer_formats)
export(set_stats_as_columns)
export(set_target_var)
export(set_total_row_label)
export(set_treat_var)
export(set_where)
export(str_extract_fmt_group)
export(str_extract_num)
export(str_indent_wrap)
export(tplyr_layer)
export(tplyr_meta)
export(tplyr_table)
export(treat_grps)
export(treat_var)
export(use_template)
importFrom(assertthat,assert_that)
importFrom(dplyr,across)
importFrom(dplyr,add_tally)
importFrom(dplyr,anti_join)
importFrom(dplyr,arrange)
importFrom(dplyr,as_tibble)
importFrom(dplyr,between)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,count)
importFrom(dplyr,cur_column)
importFrom(dplyr,cur_group)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,do)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,group_keys)
importFrom(dplyr,group_modify)
importFrom(dplyr,if_else)
importFrom(dplyr,inner_join)
importFrom(dplyr,lag)
importFrom(dplyr,left_join)
importFrom(dplyr,matches)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_all)
importFrom(dplyr,mutate_at)
importFrom(dplyr,mutate_if)
importFrom(dplyr,n)
importFrom(dplyr,n_distinct)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,row_number)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,slice_head)
importFrom(dplyr,summarize)
importFrom(dplyr,tally)
importFrom(dplyr,ungroup)
importFrom(dplyr,vars)
importFrom(dplyr,where)
importFrom(forcats,fct_collapse)
importFrom(forcats,fct_drop)
importFrom(forcats,fct_expand)
importFrom(forcats,fct_na_value_to_level)
importFrom(lifecycle,deprecate_soft)
importFrom(lifecycle,deprecate_stop)
importFrom(magrittr,"%>%")
importFrom(magrittr,extract)
importFrom(magrittr,extract2)
importFrom(purrr,flatten)
importFrom(purrr,imap)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map2_chr)
importFrom(purrr,map2_dfr)
importFrom(purrr,map_chr)
importFrom(purrr,map_dbl)
importFrom(purrr,map_dfr)
importFrom(purrr,map_int)
importFrom(purrr,map_lgl)
importFrom(purrr,pmap_chr)
importFrom(purrr,pmap_dfr)
importFrom(purrr,reduce)
importFrom(purrr,walk)
importFrom(purrr,walk2)
importFrom(rlang,":=")
importFrom(rlang,abort)
importFrom(rlang,as_label)
importFrom(rlang,as_name)
importFrom(rlang,call_args)
importFrom(rlang,call_modify)
importFrom(rlang,call_name)
importFrom(rlang,caller_env)
importFrom(rlang,current_env)
importFrom(rlang,enexpr)
importFrom(rlang,enexprs)
importFrom(rlang,enquo)
importFrom(rlang,enquos)
importFrom(rlang,env)
importFrom(rlang,env_bind)
importFrom(rlang,env_bind_active)
importFrom(rlang,env_get)
importFrom(rlang,env_has)
importFrom(rlang,env_label)
importFrom(rlang,env_names)
importFrom(rlang,env_parent)
importFrom(rlang,eval_tidy)
importFrom(rlang,expr)
importFrom(rlang,exprs)
importFrom(rlang,inform)
importFrom(rlang,is_call)
importFrom(rlang,is_empty)
importFrom(rlang,is_function)
importFrom(rlang,is_logical)
importFrom(rlang,is_named)
importFrom(rlang,is_quosure)
importFrom(rlang,is_quosures)
importFrom(rlang,list2)
importFrom(rlang,quo)
importFrom(rlang,quo_get_expr)
importFrom(rlang,quo_is_call)
importFrom(rlang,quo_is_missing)
importFrom(rlang,quo_is_null)
importFrom(rlang,quo_is_symbol)
importFrom(rlang,quo_name)
importFrom(rlang,quos)
importFrom(rlang,sym)
importFrom(rlang,syms)
importFrom(rlang,trace_back)
importFrom(rlang,warn)
importFrom(stats,IQR)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(stringr,"str_sub<-")
importFrom(stringr,fixed)
importFrom(stringr,regex)
importFrom(stringr,str_count)
importFrom(stringr,str_detect)
importFrom(stringr,str_extract)
importFrom(stringr,str_extract_all)
importFrom(stringr,str_locate_all)
importFrom(stringr,str_match)
importFrom(stringr,str_match_all)
importFrom(stringr,str_pad)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_starts)
importFrom(stringr,str_sub)
importFrom(stringr,str_trim)
importFrom(stringr,str_wrap)
importFrom(tibble,add_column)
importFrom(tibble,rownames_to_column)
importFrom(tibble,tibble)
importFrom(tidyr,complete)
importFrom(tidyr,fill)
importFrom(tidyr,nesting)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,replace_na)
importFrom(tidyr,starts_with)
importFrom(tidyselect,all_of)
importFrom(tidyselect,any_of)
importFrom(tidyselect,vars_select)
importFrom(utils,capture.output)
importFrom(utils,head)
importFrom(utils,str)
importFrom(utils,tail)
